@@ -1,10 +1,10 @@
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
 __git_branch__ = '(Not currently on any branch)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'f63a6df6909139d3a0acc06db5ebbe4856994cd8'
-__git_head_subject__ = 'Finished release v0.1.1.'
+__git_head_hash__ = '8f1d9c67f07a0b4396b99632d4c59b36aa735faf'
+__git_head_subject__ = 'empty commit after version v0.1.1'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
